
import { createRoot } from 'react-dom/client';
import App from './App.tsx';
import './index.css';
import './components/globals.css';
import './components/fixes/dropdown-fix.css'; // Load dropdown fix CSS
import './styles/critical-fixes.css'; // Load critical-fixes CSS with highest priority
import './styles/mobile-menu-fix.css'; // Load mobile menu fix CSS
import './styles/firefox-fixes.css'; // Load Firefox-specific fixes
import './components/layout/NavbarLogo.css'; // Load NavbarLogo CSS with Firefox fixes
import { setupMobileViewportFix } from './utils/mobileViewportFix';
import { applyDropdownFix } from './utils/dropdownFix';
import { injectDropdownStyles } from './utils/injectDropdownStyles';
import { forceOpaqueDropdowns } from './utils/forceOpaqueDropdowns';
import { fixRadixDropdowns } from './utils/fixRadixDropdowns';
import { applyFirefoxMobileFixes } from './utils/firefoxMobileFixes';
import { applyAndroidMobileFixes } from './utils/androidMobileFixes';

// CRITICAL: Apply our inline styles directly to document head before any rendering
document.addEventListener('DOMContentLoaded', () => {
  const style = document.createElement('style');
  style.innerHTML = `
    /* ULTRA AGGRESSIVE FIX: Forced opaque dropdowns with maximum specificity */
    html body [data-radix-popper-content-wrapper],
    html body [data-radix-popper-content-wrapper] *,
    html body [data-radix-menu-content],
    html body [data-radix-menu-content] *,
    html body [role="menu"],
    html body [role="menu"] *,
    html body [role="menuitem"],
    html body [data-radix-dropdown-menu-content],
    html body .radix-dropdown-content,
    html body .mobile-menu-container,
    html body .mobile-menu-header,
    html body .mobile-menu-content,
    html body .mobile-menu-item {
      background-color: ${document.documentElement.classList.contains('dark') ? '#222222' : '#FFFFFF'} !important;
      backdrop-filter: none !important;
      -webkit-backdrop-filter: none !important;
      opacity: 1 !important;
    }
    
    /* Direct mobile menu fixes */
    html body .mobile-menu-container {
      position: fixed !important;
      top: 0 !important;
      left: 0 !important;
      right: 0 !important;
      bottom: 0 !important;
      width: 100vw !important;
      height: 100vh !important;
      z-index: 9999 !important;
      background-color: ${document.documentElement.classList.contains('dark') ? 'rgba(34, 34, 34, 0.7)' : 'rgba(255, 255, 255, 0.7)'} !important;
      opacity: 0.7 !important;
    }
  `;
  document.head.appendChild(style);
  
  // For mobile menu specifically
  function fixMobileMenu() {
    const mobileMenus = document.querySelectorAll('.mobile-menu-container');
    mobileMenus.forEach(menu => {
      if (menu instanceof HTMLElement) {
        const isDark = document.documentElement.classList.contains('dark');
        const bgColor = isDark ? 'rgba(34, 34, 34, 0.7)' : 'rgba(255, 255, 255, 0.7)';
        
        // Force background and related properties
        menu.style.setProperty('background-color', bgColor, 'important');
        menu.style.setProperty('opacity', '0.7', 'important');
        menu.style.setProperty('backdrop-filter', 'blur(5px)', 'important');
        menu.style.setProperty('-webkit-backdrop-filter', 'blur(5px)', 'important');
        menu.style.setProperty('background-image', 'none', 'important');
        
        // Force all children elements to be transparent
        const children = menu.querySelectorAll('*');
        children.forEach(child => {
          if (child instanceof HTMLElement) {
            child.style.setProperty('background-color', 'transparent', 'important');
            child.style.setProperty('opacity', '1', 'important');
            child.style.setProperty('backdrop-filter', 'none', 'important');
            child.style.setProperty('-webkit-backdrop-filter', 'none', 'important');
            child.style.setProperty('background-image', 'none', 'important');
          }
        });
      }
    });
  }
  
  // Run fix regularly
  setInterval(fixMobileMenu, 500);
  
  // Also run when classes change
  const observer = new MutationObserver((mutations) => {
    mutations.forEach((mutation) => {
      if (mutation.attributeName === 'class') {
        fixMobileMenu();
      }
    });
  });
  
  observer.observe(document.documentElement, { attributes: true });
});

// Create an IIFE to initialize and clean up
(() => {
  // Get root element
  const rootElement = document.getElementById('root');
  if (!rootElement) {
    console.error('Root element not found');
    return;
  }

  // Create the React root and render the app
  try {
    // Apply mobile viewport fixes
    setupMobileViewportFix();

    // Apply Firefox Mobile and Android specific fixes
    applyFirefoxMobileFixes();
    applyAndroidMobileFixes();

    // Apply ALL dropdown opacity fixes (extreme multi-layered approach)
    applyDropdownFix();
    injectDropdownStyles();
    forceOpaqueDropdowns();
    fixRadixDropdowns(); // Last resort direct DOM manipulation

    // Apply fixes again after the page has loaded
    window.addEventListener('load', () => {
      setTimeout(() => {
        applyDropdownFix();
        injectDropdownStyles();
        forceOpaqueDropdowns();
        fixRadixDropdowns();
      }, 500);
    });

    // Create root and render app
    const root = createRoot(rootElement);
    root.render(<App />);
  } catch (error) {
    console.error('Error initializing application:', error);
    // Fallback rendering in case of error
    rootElement.innerHTML = `
      <div style="padding: 20px; text-align: center;">
        <h1>Loading Error</h1>
        <p>There was a problem loading the application. Please try refreshing the page.</p>
        <p>Error details: ${error instanceof Error ? error.message : String(error)}</p>
      </div>
    `;
  }
})();
